# ThreadExample_VAC by David Bowland
# Demonstrates basic use of the ThreadPool library

from __future__ import with_statement # For URLs
from contextlib import closing # For "with" statement
from threadpool import * # ThreadPool

import es
import re
import urllib2

###

BAN_FROM_SERVER = False # Set to True to ban VAC-banned players from the server
COMMUNITY_URL = 'http://steamcommunity.com/profiles/%s?xml=1'
RE_BANNED = re.compile(r'\<vacBanned\>[1-9]\<\/vacBanned\>')
RE_STEAMID = re.compile(r'^STEAM\_\d\:\d\:\d{3,}$')

###

# This function will be executed in a separate thread
@threaded()
def isBanned(steamid, name):
   # Open the URL
   url = COMMUNITY_URL % steamIDToCommunityID(steamid)
   # u = urllib2.urlopen(url)
   with closing(urllib2.urlopen(url)) as u:
      # Read the data and determine if the player is banned
      result = bool(RE_BANNED.search(u.read()))
   # Pass the result to the callback function
   threadSafeCall(bannedResult, (name, result, steamid))


def steamIDToCommunityID(steamid):
   """ Converts Steam IDs to community IDs """
   x, server, id = steamid.split(':')
   return int(id) * 2 + int(server) + 76561197960265728L

###

def es_player_validated(event_var):
   # Execute the isBanned function in the separate thread
   # We pass the player's name as we want that information in the callback
   steamid = event_var['networkid']
   if RE_STEAMID.match(steamid):
      isBanned(steamid, event_var['name'])


def bannedResult(name, result, steamid):
   # Because this function uses es commands we want it to be executed in the main thread
   bannedtext = '#darkgreenBANS ON RECORD' if result else '#lightgreenIN GOOD STANDING'
   es.msg('#multi', '#lightgreen' + name + '#default VAC status: ' + bannedtext)

   # Ban the player from the server if necessary
   if result and BAN_FROM_SERVER:
      es.server.insertcmd('banid 0 %s;writeid' % steamid)
      if es.getuserid(steamid):
         es.server.insertcmd('kickid %s VAC banned' % steamid)